import { render, screen, waitFor } from '@/test-utils/index';
import userEvent from '@testing-library/user-event';
import React from 'react';

import { AutocompleteMockList } from './mock/MockData';
import { OptionUiComponent } from './mock/MockUI';
import NsAutocomplete from './NsAutocomplete';

const commonProps = {
    value: '',
    inputValue: '',
    onInputChange: jest.fn(),
    onChange: jest.fn(),
    options: AutocompleteMockList,
    placeholder: 'autocomplete-input',
    OptionsUI: OptionUiComponent,
};
describe('CustomAutocomplete', () => {
    it('1. should render autocomplete component', () => {
        render(<NsAutocomplete {...commonProps} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
    });
    it('2. check that onInputChange gets called', async () => {
        const onInputChangeMock = jest.fn();
        render(<NsAutocomplete {...commonProps} onInputChange={onInputChangeMock} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
        await userEvent.type(autocompleteInput, 'GS Facial');
        expect(onInputChangeMock).toHaveBeenCalled();
    }, 100000);

    it('3. displays options when typing in the input', async () => {
        const onInputChangeMock = jest.fn();
        render(<NsAutocomplete {...commonProps} onInputChange={onInputChangeMock} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(
            () => {
                const option1 = screen.getByText('GS Facial Gels 2pk Subscription');
                expect(option1).toBeInTheDocument();
            },
            { timeout: 5000 }
        );
    }, 40000);

    it('4. selects an option when clicking on it', async () => {
        const onChangeMock = jest.fn();
        render(<NsAutocomplete {...commonProps} onChange={onChangeMock} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(async () => {
            const optionLi = screen.getByText('GS Facial Spa');
            await userEvent.click(optionLi);
        });
        expect(onChangeMock).toHaveBeenCalled();
    }, 40000);

    it('5. should load more options when clicking load more button', async () => {
        render(
            <NsAutocomplete
                seeMore={{
                    text: '',
                    show: true,
                    onSeeMore: () => ({}),
                }}
                {...commonProps}
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(async () => {
            const loadMoreButton = screen.getByTestId('autocomplete-loadmore-id');
            await userEvent.click(loadMoreButton);
        });
    }, 40000);

    it('6. should clear options when clicking clear button', async () => {
        render(
            <NsAutocomplete
                clear={{
                    text: '',
                    show: true,
                    onClear: () => ({}),
                }}
                {...commonProps}
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(async () => {
            const clearButton = screen.getByTestId('autocomplete-clear-id');
            await userEvent.click(clearButton);
        });
    }, 40000);
});
