import { Dispatch, MutableRefObject, SetStateAction, useCallback } from 'react';

import { OptionsProps } from '../..';
import { AutoCompleteButton } from './AutoCompleteButton';

type SeeMoreButtonProps = {
    text?: string;
    show?: boolean;
    onSeeMore?(): void;
    options: OptionsProps[];
    setScrollTopPosition: Dispatch<SetStateAction<number>>;
    listboxRef: MutableRefObject<HTMLUListElement | null>;
};

export const SeeMoreButton = (props: SeeMoreButtonProps) => {
    const {
        show = false,
        text = 'See More Results',
        onSeeMore,
        options,
        listboxRef,
        setScrollTopPosition,
    } = props || {};

    const handleSeeMore = useCallback(() => {
        /*  Remember the current scroll position */
        if (options?.length > 0 && listboxRef?.current) {
            const lastScrollPosition = listboxRef.current?.scrollTop;
            if (lastScrollPosition) {
                setScrollTopPosition(lastScrollPosition);
            }
        }
        if (onSeeMore && typeof onSeeMore === 'function') {
            onSeeMore();
        }
    }, [listboxRef, onSeeMore, options?.length, setScrollTopPosition]);
    return <AutoCompleteButton show={show} text={text} onClick={handleSeeMore} testId="autocomplete-loadmore-id" />;
};
