import { ShoppingCart } from '@mui/icons-material';
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsTypography } from '../';
import NsBrandWrapper from './NsBrandWrapper';
import NsBrandLogo from './NsBrandLogo';
import NsBgCard from './NsBgCard';
import NsButton from '../button/NsButton';
import cardSizes from './cardSizes';

type NsBrandCardProps = {
    title?: string;
    brandImageUrl: string;
    backgroundImageUrl: string;
    size?: 'small' | 'large';
    button?: boolean;
    onClick?: () => void;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ size }) => {
    const { small, large } = cardSizes;
    let width, height;

    if (size === 'small') {
        width = small.width;
        height = small.height;
    } else {
        width = large.width;
        height = large.height;
    }

    return {
        width,
        display: 'flex',
        alignItems: 'start',
        justifyContent: 'center',
        position: 'relative',
        flexDirection: 'column',
        '.brand-title': {
            marginTop: '15px',
            fontSize: '20px',
            display: 'inline-block',
            wordBreak: 'break-word',
        },
        ':hover': {
            '.brand-title': {
                opacity: '0.7',
            },
        },
        '.cta': {
            marginTop: '15px',
        },
        '.image': {
            width,
            height,
            backgroundSize: 'cover',
            backgroundPosition: 'center',
        },
    };
});
export default function NsBrandCard({
    title,
    brandImageUrl,
    backgroundImageUrl,
    button,
    size,
    onClick,
}: NsBrandCardProps) {
    return (
        <CardContainer role="brand-card" component="div" data-testid="brand-card" size={size} onClick={onClick}>
            <NsBgCard backgroundImageUrl={backgroundImageUrl} className="image">
                <NsBrandWrapper>
                    <NsBrandLogo component="img" image={brandImageUrl} />
                </NsBrandWrapper>
            </NsBgCard>
            {title ? (
                <NsTypography variant="h3" className="brand-title">
                    {title}
                </NsTypography>
            ) : null}
            {button ? (
                <NsButton
                    className="cta"
                    darkModeEnabled={false}
                    variant="outlined"
                    fullWidth={true}
                    endIcon={<ShoppingCart />}
                >
                    Add to Cart
                </NsButton>
            ) : null}
        </CardContainer>
    );
}
