import { NsLink, NsImage } from '../';
import Box from '@mui/material/Box';
import { AdditionalProps } from '../common.types';
import { styled } from '@nuskin/foundation-theme';

type NsHeroCardLevel1Props = {
    text: string;
    body: string;
    cardLink: { href: string; title: string };
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    onClick: () => void;
} & AdditionalProps;

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'row' as 'row', // https://github.com/cssinjs/jss/issues/1344
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        '.content': {
            width: '50%',
            height: '100%',
            padding: '50px',
            paddingLeft: '100px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.image': {
            width: 'auto',
            height: '100%',
            display: 'block',
        },
        '.body-title': {
            fontSize: '36px',
            lineHeight: '44px',
            marginBottom: '20px',
        },
        '.body-text': {
            fontSize: '18px',
            marginBottom: '20px',
        },
        '.action-link': {
            display: 'flex',
            height: '44px',
            flexDirection: 'column',
            justifyContent: 'center',
            alignItems: 'center',
            gap: '10px',
            flexShrink: 0,
            alignSelf: 'stretch',
            backgroundColor: '#252525',
            color: '#fff',
            marginTop: '10px',
            borderRadius: '4px',

            ':hover': {
                textDecoration: 'none',
                backgroundColor: '#252w16',
            },
        },
        '@media (max-width: 768px)': {
            display: 'block',
            height: 'auto',
            backgroundColor: '#edece9',
            '.content': {
                position: 'static',
                width: '100%',
                padding: '20px',
            },
        },
    };
});

const NsHeroCardLevel1 = ({
    text,
    body,
    cardLink,
    backgroundImageUrl,
    backgroundImageAlt,
    onClick,
    additionalProps,
}: NsHeroCardLevel1Props) => {
    return (
        <CardContainer data-testid={additionalProps?.testid} onClick={onClick}>
            <div className="image">
                <NsImage height={'auto'} width={'100%'} alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <article className="body-title">{text}</article>
                <article className="body-text">{body}</article>
                <NsLink className="action-link" href={cardLink.href}>
                    {cardLink.title}
                </NsLink>
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel1;
