import { NsLink, NsImage, NsIcon, NsIconNameType } from '../';
import Box from '@mui/material/Box';
import { AdditionalProps } from '../common.types';
import { styled } from '@nuskin/foundation-theme';

type NsHeroCardLevel2Props = {
    brand: string;
    text: string;
    body: string;
    icon: NsIconNameType;
    cardLink: { href: string; title: string };
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    onClick: () => void;
} & AdditionalProps;

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'row' as 'row', // https://github.com/cssinjs/jss/issues/1344
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        '.content': {
            height: '100%',
            padding: '50px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.image': {
            width: 'auto',
            height: '100%',
            display: 'block',
        },
        '.brand-container': {
            backgroundColor: '#fff',
            width: 'fit-content',
            paddingLeft: '10px',
            paddingRight: '10px',
        },
        '.body-title': {
            fontSize: '36px',
            lineHeight: '44px',
            marginBottom: '5px',
        },
        '.body-text': {
            fontSize: '18px',
            fontWeight: 700,
            marginBottom: '5px',
        },
        '.cta': {
            display: 'flex',
            flexDirection: 'column' as 'column',
            width: 'fit-content',
            borderBottom: '1px solid black',
            ':hover': {
                opacity: '0.8',
            },
        },
        '.action-link': {
            display: 'flex',
            fontWeight: 600,
            ':hover': {
                textDecoration: 'none',
            },
        },
        '.icon': {
            marginLeft: '10px',
        },
        '@media (max-width: 768px)': {
            '.content': {
                padding: '5%',
            },
            '.body-title': {
                fontSize: '18px',
                lineHeight: '44px',
                marginBottom: '5px',
            },
            '.body-text': {
                fontSize: '12px',
                fontWeight: 700,
                marginBottom: '5px',
            },
        },
    };
});

const NsHeroCardLevel2 = ({
    brand,
    text,
    body,
    cardLink,
    backgroundImageUrl,
    backgroundImageAlt,
    additionalProps,
    icon,
    onClick,
}: NsHeroCardLevel2Props) => {
    return (
        <CardContainer data-testid={additionalProps?.testid} onClick={onClick}>
            <div className="image">
                <NsImage height={'auto'} width={'100%'} alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <div className="brand-container">
                    <article>{brand}</article>
                </div>
                <article className="body-title">{text}</article>
                <article className="body-text">{body}</article>
                <div className="cta">
                    <NsLink className="action-link" href={cardLink.href}>
                        {cardLink.title}
                        <NsIcon className="icon" name={icon} />
                    </NsLink>
                </div>
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel2;
