import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsButton, NsImage } from '..';

type NsMediumCardProps = {
    title: string;
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    cardLink: { href: string; title: string };
};

const CardContainer = styled(Box)(() => {
    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
        },
        '.subtitle': {
            fontSize: '11px',
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: '16px',
            fontWeight: '400',
            marginTop: '10px',
        },
        '.action-link': {
            marginTop: '10px',
            fontSize: '14px',
            alignSelf: 'start',
        },
    };
});

export default function NsMediumCard({
    title,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    cardLink,
}: NsMediumCardProps) {
    return (
        <CardContainer role="medium-card" component="div" data-testid="medium-card">
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <article className="title">{title}</article>
                <article className="subtitle">{subtitle}</article>
                <NsButton className="action-link" variant="outlined" color="primary" href={cardLink.href}>
                    {cardLink.title}
                </NsButton>
            </div>
        </CardContainer>
    );
}
