import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsImage, NsLink } from '../';

type NsSmallFullCardProps = {
    title: string;
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    cardLink: { href: string; title: string };
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundColor: '#fff',
        display: 'flex',
        height: '320px',
        width: '375px',
        position: 'relative',
        '.image': {
            width: '100%',
            height: '100%',
            objectFit: 'cover',
        },
        '.gradientOverlay': {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            background: 'linear-gradient(to top, rgba(0,0,0,0.6) 0%, transparent 50%);',
        },
        '.content': {
            position: 'absolute',
            height: '100%',
            width: '100%',
            padding: '40px 40px 25px 30px',
            display: 'flex',
            flexDirection: 'column',
        },
        '.subtitle': {
            color: '#fff',
            fontSize: '11px',
            fontWeight: '400',
            marginTop: 'auto',
        },
        '.title': {
            color: '#fff',
            fontSize: '26px',
            fontWeight: '400',
            marginTop: '20px',
        },
        '.action-link': {
            display: 'flex',
            justifyContent: 'center',
            backgroundColor: '#252525',
            color: '#fff',
            marginTop: '20px',
            borderRadius: '4px',
            padding: '10px',
            width: '70%',
            ':hover': {
                textDecoration: 'none',
                backgroundColor: '#3e3e3e',
            },
        },
    };
});

export default function NsSmallFullCard({
    title,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    cardLink,
}: NsSmallFullCardProps) {
    return (
        <CardContainer role="small-full-card" component="div" data-testid="small-full-card">
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="gradientOverlay"></div>
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                <NsLink className="action-link" href={cardLink.href}>
                    {cardLink.title}
                </NsLink>
            </div>
        </CardContainer>
    );
}
