import React from 'react';
import { render, screen, fireEvent } from '@testing-library/react';
import '@testing-library/jest-dom';
import NsCheckoutCard from '../NsCheckoutCard';

describe('NsCheckoutCard component', () => {
    const props = {
        title: 'Section Title',
        address: 'Address',
        icon: 'home' as 'home',
        onClick: jest.fn(),
    };

    it('1. renders with correct content and styles', () => {
        render(<NsCheckoutCard {...props} />);

        const checkoutCard = screen.getByTestId('checkout-card');
        expect(checkoutCard).toBeInTheDocument();

        const titleElement = screen.getByText(props.title);
        expect(titleElement).toBeInTheDocument();

        const addressElement = screen.getByText(props.address);
        expect(addressElement).toBeInTheDocument();

        const changeLink = screen.getByText('CHANGE');
        expect(changeLink).toBeInTheDocument();
    });

    it('2. toggles dropdown icon on click', () => {
        render(<NsCheckoutCard {...props} />);

        const dropdownIcon = screen.getByTestId('dropdown-icon');

        fireEvent.click(dropdownIcon);
        // expect(dropdownIcon).toHaveAttribute('name', 'arrowUp');

        // fireEvent.click(dropdownIcon);
        // expect(dropdownIcon).toHaveAttribute('name', 'arrowDown');
    });

    it('3. calls onClick when the card is clicked', () => {
        render(<NsCheckoutCard {...props} />);

        const checkoutCard = screen.getByTestId('checkout-card');
        fireEvent.click(checkoutCard);

        expect(props.onClick).toHaveBeenCalled();
    });
});
