import React from 'react';
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { NsHeroCardLevel2 } from '../';

describe('NsHeroCardLevel2 component', () => {
    const props = {
        brand: 'Beauty focus™',
        text: 'Current shop deals',
        body: 'Lumispa, sunscreen and more',
        icon: 'home' as 'home',
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'Discover more',
        },
        backgroundImageUrl: 'https://media.nuskin.com/m/5f1c423bb57589f0/webimage-autumn-sale-carousel.png',
        backgroundImageAlt: 'lash brow serum carousel',
        additionalProps: {
            testid: 'hero-card-level-2',
        },
        onClick: jest.fn(),
    };

    it('1. renders with correct content and styles', () => {
        render(<NsHeroCardLevel2 {...props} />);

        const cardContainer = screen.getByTestId('hero-card-level-2');
        expect(cardContainer).toBeInTheDocument();

        const brandText = screen.getByText('Beauty focus™');
        expect(brandText).toBeInTheDocument();

        const textContent = screen.getByText('Current shop deals');
        expect(textContent).toBeInTheDocument();

        const bodyContent = screen.getByText('Lumispa, sunscreen and more');
        expect(bodyContent).toBeInTheDocument();

        const discoverMoreLink = screen.getByRole('link', { name: 'Discover more' });
        expect(discoverMoreLink).toBeInTheDocument();
    });

    it.skip('2. calls onClick when the card is clicked', () => {
        render(<NsHeroCardLevel2 {...props} />);

        const cardContainer = screen.getByTestId('hero-card-level-2');
        userEvent.click(cardContainer);

        expect(props.onClick).toHaveBeenCalled();
    });
});
