import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { NsLargeCard } from '../';

describe('NsLargeCard component', () => {
    const props = {
        title: 'Title',
        subtitle: 'Subtitle',
        intro: 'Introduction sentence',
        icon: 'cart' as 'cart',
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'Button Text',
        },
        backgroundImageUrl: 'https://example.com/image.jpg',
        backgroundImageAlt: 'Image Alt',
    };

    it('1. renders with correct content and styles', () => {
        render(<NsLargeCard {...props} />);

        expect(screen.getByText(props.title)).toBeInTheDocument();
        expect(screen.getByText(props.subtitle)).toBeInTheDocument();
    });

    it('2. triggers the link when clicked', () => {
        render(<NsLargeCard {...props} />);

        userEvent.click(screen.getByRole('link'));
    });

    it('3. renders NsLink and NsIcon when isHorizontal is true', () => {
        render(<NsLargeCard {...props} isHorizontal={true} />);

        const actionLink = screen.getByText(props.cardLink.title);
        expect(actionLink).toBeInTheDocument();

        const parentDiv = actionLink.closest('.cta');
        expect(parentDiv).toBeInTheDocument();
    });
});
