import type { StoryObj, Meta } from '@storybook/react';
import { within, userEvent } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsHeroCardLevel1 } from '../';

type ComponentType = typeof NsHeroCardLevel1;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsHeroCardLevel1,
    title: 'Components/Containers/Card/NsHeroCardLevel1',
    argTypes: {
        onClick: { action: 'clicked' },
    },
    decorators: [withCenterDecorator],
} as MetaStory;

const text = 'A skin ready for winter';
const body = 'We have brought these discoveries to life through our powerful skin care products and supplements.';
const host = 'https://media.nuskin.com/';

export const Default: Story = {
    args: {
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'SHOP NOW',
        },
        text,
        body,
        backgroundImageUrl: `${host}m/9734240cc191163/webimage-lash-brow-serum-carousel-image-launch.png`,
        backgroundImageAlt: 'lash brow serum carousel',
        additionalProps: {
            testid: 'hero-card-level-1',
        },
    },
    play: async ({ canvasElement }: any) => {
        const canvas = within(canvasElement);
        userEvent.hover(canvas.getByTestId('hero-card-level-1'));
        userEvent.hover(canvas.getByRole('link'));
        expect(canvas.getByText(text)).toBeInTheDocument();
        expect(canvas.getByText(body)).toBeInTheDocument();
    },
};
