import type { StoryObj, Meta } from '@storybook/react';
import { within, userEvent } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsHeroCardLevel2 } from '../';

type ComponentType = typeof NsHeroCardLevel2;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsHeroCardLevel2,
    title: 'Components/Containers/Card/NsHeroCardLevel2',
    argTypes: {
        onClick: { action: 'clicked' },
    },
    decorators: [withCenterDecorator],
} as MetaStory;

const text = 'Current shop deals';
const body = 'Lumispa, sunscreen and more';
const icon = 'home';
const brand = 'Beauty focus™';
const host = 'https://media.nuskin.com/';

export const Default: Story = {
    args: {
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'Discover more',
        },
        text,
        body,
        icon,
        brand,
        backgroundImageUrl: `${host}m/5f1c423bb57589f0/webimage-autumn-sale-carousel.png`,
        backgroundImageAlt: 'lash brow serum carousel',
        additionalProps: {
            testid: 'hero-card-level-2',
        },
    },
    play: async ({ canvasElement }: any) => {
        const canvas = within(canvasElement);
        userEvent.hover(canvas.getByTestId('hero-card-level-2'));
        userEvent.hover(canvas.getByRole('link'));
        expect(canvas.getByText(text)).toBeInTheDocument();
        expect(canvas.getByText(body)).toBeInTheDocument();
        expect(canvas.getByText(brand)).toBeInTheDocument();
    },
};
